<?php
/*
Plugin Name: Latin Squares
Plugin URI: https://blog.tremlas.com/wordpress-plugins/latin-squares-plugin-details/
Description: Adds a shortcode that inserts a helper for latin squares
Version: 3.161.0
Author: David Vines
Author URI: http://blog.tremlas.com
License:  Creative Commons License
*/
/* © Copyright 2014, 2021 David Vines

   Creative Commons License

   This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
*/

include_once 'common.php';

/**
 * Shortcode to add the version of the plugin
 */
function djv_latinSquare_latinSquareVersion_shortcode() {
	return 'Latin Squares Version 3.161.0';
}
add_shortcode( 'latinsquareVersion', 'djv_latinSquare_latinSquareVersion_shortcode' );

/**
 * Inserts a helper for puzzles that involve a single latin square.
 *
 * Only one can be inserted per page in this implementation
 *
 * A 'size' attribute can be specified to define the size of the
 * latin square, defaults to 6.
 */

// Now for a shortcode that can be used to get links and/or tables for the characters
function djv_latinSquare_shortcode( $attr, $content = null ) {
	$plugin_url = plugin_dir_url(__FILE__);
	wp_enqueue_script('djv_latin', $plugin_url.'js/latin.js' );
	wp_enqueue_script('djv_latinsquare', $plugin_url.'js/latinsquare.js' );
	wp_enqueue_style('djv_latinsquare_css', $plugin_url.'css/latin.css');


	if ( isset($attr) && isset( $attr['size'] ) ) {
		$size = (int)$attr['size'];
	} else {
		$size = 6;
	}

	$text  = '<script>' . PHP_EOL;
	$text .= 'window.onload = function() { reset(' . $size . '); }' . PHP_EOL;
	$text .= '</script>' . PHP_EOL;
	$text .= '<table id="table">' . PHP_EOL;

	for($i = 1; $i <= $size; $i++) {
		$text .= '<tr>' . PHP_EOL;

		for ($j = 1; $j <= $size; $j++) {
			$text .= '<td class="cell"><table>' . PHP_EOL;
			for($notk = 0; $notk < ceil(($size)/3); $notk++ ) {
				$text .= '<tr>' . PHP_EOL;

				for($k = $notk*3+1; $k <= min(($notk+1)*3,$size); $k++) {
					$text .= '<td><button id="' . $i . $j . $k . '" class="numberbutton" onclick="ruleout(' . $i . ',' . $j . ',' . $k . ')">' . $k . '</button></td>' . PHP_EOL;
				}

				$text .= '</tr>' . PHP_EOL;
			}
			$text .= '</table></td>' . PHP_EOL;
		}

		$text .= '</tr>' . PHP_EOL;
	}

	$text .= '</table>' . PHP_EOL;
	$text .= '<button id="reset" onclick="reset(' . $size . ')">Reset the table</button>' . PHP_EOL;
	$text .= '<input type="checkbox" id="mode" value="eliminate" onchange="changemode()" checked>Eliminate candidates</input>' . PHP_EOL;
	$text .= '<button id="undo" onclick="undo()">Undo</button>' . PHP_EOL;
	$text .= '<button id="redo" onclick="redo()">Redo</button>' . PHP_EOL;

	return $text;
}

add_shortcode( 'latinsquare', 'djv_latinSquare_shortcode' );

/* --------------------- Functions for updating plugins ------------------------------ */
function djv_latinSquare_get_remote_update_from( $urlbase, $slug ) {
 $url = $urlbase . '/wp-content/uploads/jsons/' . $slug . '.json';
 $remote =  wp_remote_get( $url, array( 'timeout' => 10, 'headers' => array( 'Accept' => 'application/json' ) ) );
 if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
  $remote['urlbase'] = $urlbase;
 }
 return $remote;
}
function djv_latinSquare_get_remote_update_info( $slug ) {
 $remote = get_transient( 'djv_update_' . $slug );
 if (false == $remote || is_wp_error($remote) || !isset( $remote['response']['code'] ) || 200 !== $remote['response']['code'] || empty( $remote['body'] ) ) {
  $remote = djv_latinSquare_get_remote_update_from( get_site_url( ), $slug );
  if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
   set_transient( 'djv_update_' . $slug, $remote, 10 ); // Save for only 10 seconds here
  } else {
   $remote = djv_latinSquare_get_remote_update_from( 'https://blog.tremlas.com', $slug );
   if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
    set_transient( 'djv_update_' . $slug, $remote, 43200 ); // Save for 12 hours
   }
  }
 }
 if ( !is_wp_error( $remote ) && isset( $remote['response']['code'] ) && 200 == $remote['response']['code'] && ! empty( $remote['body'] ) ) {
  $body = json_decode( $remote['body'] );
  $info = new StdClass();
  $info->name = 'Latin Squares';
  $info->slug = $slug;
  $info->version = $body->version;
  $info->requires = $body->requires;
  $info->author = '<a href="' . $body->author_profile . '">' . $body->author . '</a>';
  $info->download_link = $remote['urlbase'] . '/' . $body->download_url;
  $info->trunk = $remote['urlbase'] . '/' . $body->download_url;
  $info->last_updated = $body->last_updated;
  $info->sections = array(
    'description'  => implode( "\n", $body->sections->description ),
    'installation' => implode( "\n", $body->sections->installation ),
    'changelog'    => implode( "\n", $body->sections->changelog ),
  );
  $info->homepage = $remote['urlbase'] . '/' . $body->homepage;
  return $info;
 }
 return false;
}

function djv_latinSquare_check_for_update( $name, $slug ) {
 $info = djv_latinSquare_get_remote_update_info( $slug );
 if ( false == $info ) {
  return false;
 }
 if ( version_compare( '3.161.0', $info->version, '<' ) && version_compare( $info->requires, get_bloginfo( 'version' ), '<' ) ) {
  $update = (object) array(
    'id'            => $name,
    'slug'          => $slug,
    'plugin'        => $name,
    'new_version'   => $info->version,
    'url'           => $info->homepage,
    'package'       => $info->download_link,
    'icons'         => array(),
    'banners'       => array(),
    'banners_rtl'   => array(),
    'tested'        => '',
    'requires_php'  => '',
    'compatability' => new StdClass()
  );
  return $update;
 } else {
  return false;
 }
}

function djv_latinSquare_pre_set_site_transient_update_plugins( $transient ) {
	$id = 'latinSquares/latinSquarePlugin.php';
	$name = 'Latin Squares';
	$slug = 'latinSquares';
	return djv_plugin_pre_set_site_transient( $transient, $id, $name, $slug, '3.161.0' );
}
add_filter( 'pre_set_site_transient_update_plugins', 'djv_latinSquare_pre_set_site_transient_update_plugins' );

function djv_latinSquares_plugin_info( $result, $action, $args ) {
	$name = 'Latin Squares';
	$slug = 'latinSquares';
	if ( 'plugin_information' !== $action ) {
		return $result;
	}
	if ( $slug !== $args->slug) {
		return $result;
	}
	return djv_plugin_get_remote_update_info( $name, $slug );
}
add_filter( 'plugins_api', 'djv_latinSquares_plugin_info', 10, 3 );
?>